Class: Google::Apis::CloudcommerceprocurementV1::Account

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudcommerceprocurement_v1/classes.rb,
lib/google/apis/cloudcommerceprocurement_v1/representations.rb,
lib/google/apis/cloudcommerceprocurement_v1/representations.rb

Overview

Represents an account that was established by the customer on the service provider's system.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Account

Returns a new instance of Account.



83
84
85
# File 'lib/google/apis/cloudcommerceprocurement_v1/classes.rb', line 83

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#approvalsArray<Google::Apis::CloudcommerceprocurementV1::Approval>

Output only. The approvals for this account. These approvals are used to track actions that are permitted or have been completed by a customer within the context of the provider. This might include a sign up flow or a provisioning step, for example, that the provider can admit to having happened. Corresponds to the JSON property approvals



36
37
38
# File 'lib/google/apis/cloudcommerceprocurement_v1/classes.rb', line 36

def approvals
  @approvals
end

#create_timeString

Output only. The creation timestamp. Corresponds to the JSON property createTime

Returns:

  • (String)


41
42
43
# File 'lib/google/apis/cloudcommerceprocurement_v1/classes.rb', line 41

def create_time
  @create_time
end

#input_propertiesHash<String,Object>

Output only. The custom properties that were collected from the user to create this account. Corresponds to the JSON property inputProperties

Returns:

  • (Hash<String,Object>)


47
48
49
# File 'lib/google/apis/cloudcommerceprocurement_v1/classes.rb', line 47

def input_properties
  @input_properties
end

#nameString

Output only. The resource name of the account. Account names have the form accounts/account_id`. Corresponds to the JSON propertyname`

Returns:

  • (String)


53
54
55
# File 'lib/google/apis/cloudcommerceprocurement_v1/classes.rb', line 53

def name
  @name
end

#providerString

Output only. The identifier of the service provider that this account was created against. Each service provider is assigned a unique provider value when they onboard with Cloud Commerce platform. Corresponds to the JSON property provider

Returns:

  • (String)


60
61
62
# File 'lib/google/apis/cloudcommerceprocurement_v1/classes.rb', line 60

def provider
  @provider
end

#reseller_parent_billing_accountString

Output only. The reseller parent billing account of the account's corresponding billing account, applicable only when the corresponding billing account is a subaccount of a reseller. Included in responses only for view: ACCOUNT_VIEW_FULL. Format: billingAccounts/billing_account_id Corresponds to the JSON property resellerParentBillingAccount

Returns:

  • (String)


68
69
70
# File 'lib/google/apis/cloudcommerceprocurement_v1/classes.rb', line 68

def 
  @reseller_parent_billing_account
end

#stateString

Output only. The state of the account. This is used to decide whether the customer is in good standing with the provider and is able to make purchases. An account might not be able to make a purchase if the billing account is suspended, for example. Corresponds to the JSON property state

Returns:

  • (String)


76
77
78
# File 'lib/google/apis/cloudcommerceprocurement_v1/classes.rb', line 76

def state
  @state
end

#update_timeString

Output only. The last update timestamp. Corresponds to the JSON property updateTime

Returns:

  • (String)


81
82
83
# File 'lib/google/apis/cloudcommerceprocurement_v1/classes.rb', line 81

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



88
89
90
91
92
93
94
95
96
97
# File 'lib/google/apis/cloudcommerceprocurement_v1/classes.rb', line 88

def update!(**args)
  @approvals = args[:approvals] if args.key?(:approvals)
  @create_time = args[:create_time] if args.key?(:create_time)
  @input_properties = args[:input_properties] if args.key?(:input_properties)
  @name = args[:name] if args.key?(:name)
  @provider = args[:provider] if args.key?(:provider)
  @reseller_parent_billing_account = args[:reseller_parent_billing_account] if args.key?(:reseller_parent_billing_account)
  @state = args[:state] if args.key?(:state)
  @update_time = args[:update_time] if args.key?(:update_time)
end