Class: Google::Apis::CloudcommerceprocurementV1::RejectAccountRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudcommerceprocurement_v1/classes.rb,
lib/google/apis/cloudcommerceprocurement_v1/representations.rb,
lib/google/apis/cloudcommerceprocurement_v1/representations.rb

Overview

Request message for PartnerProcurementService.RejectAccount.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RejectAccountRequest

Returns a new instance of RejectAccountRequest.



614
615
616
# File 'lib/google/apis/cloudcommerceprocurement_v1/classes.rb', line 614

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#approval_nameString

The name of the approval being rejected. If absent and there is only one approval possible, that approval will be rejected. If absent and there are many approvals possible, the request will fail with a 400 Bad Request. Optional. Corresponds to the JSON property approvalName

Returns:

  • (String)


606
607
608
# File 'lib/google/apis/cloudcommerceprocurement_v1/classes.rb', line 606

def approval_name
  @approval_name
end

#reasonString

Free form text string explaining the rejection reason. Max allowed length: 256 bytes. Longer strings will be truncated. Corresponds to the JSON property reason

Returns:

  • (String)


612
613
614
# File 'lib/google/apis/cloudcommerceprocurement_v1/classes.rb', line 612

def reason
  @reason
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



619
620
621
622
# File 'lib/google/apis/cloudcommerceprocurement_v1/classes.rb', line 619

def update!(**args)
  @approval_name = args[:approval_name] if args.key?(:approval_name)
  @reason = args[:reason] if args.key?(:reason)
end