Class: Google::Apis::CloudcommerceprocurementV1::SuspendEntitlementRequest
- Inherits:
-
Object
- Object
- Google::Apis::CloudcommerceprocurementV1::SuspendEntitlementRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudcommerceprocurement_v1/classes.rb,
lib/google/apis/cloudcommerceprocurement_v1/representations.rb,
lib/google/apis/cloudcommerceprocurement_v1/representations.rb
Overview
Request message for ParterProcurementService.SuspendEntitlement. This is not yet supported.
Instance Attribute Summary collapse
-
#reason ⇒ String
A free-form reason string, explaining the reason for suspension request.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SuspendEntitlementRequest
constructor
A new instance of SuspendEntitlementRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SuspendEntitlementRequest
Returns a new instance of SuspendEntitlementRequest.
694 695 696 |
# File 'lib/google/apis/cloudcommerceprocurement_v1/classes.rb', line 694 def initialize(**args) update!(**args) end |
Instance Attribute Details
#reason ⇒ String
A free-form reason string, explaining the reason for suspension request.
Corresponds to the JSON property reason
692 693 694 |
# File 'lib/google/apis/cloudcommerceprocurement_v1/classes.rb', line 692 def reason @reason end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
699 700 701 |
# File 'lib/google/apis/cloudcommerceprocurement_v1/classes.rb', line 699 def update!(**args) @reason = args[:reason] if args.key?(:reason) end |