Class: Google::Apis::CloudcommerceprocurementV1::ApproveAccountRequest
- Inherits:
-
Object
- Object
- Google::Apis::CloudcommerceprocurementV1::ApproveAccountRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudcommerceprocurement_v1/classes.rb,
lib/google/apis/cloudcommerceprocurement_v1/representations.rb,
lib/google/apis/cloudcommerceprocurement_v1/representations.rb
Overview
Request message for PartnerProcurementService.ApproveAccount.
Instance Attribute Summary collapse
-
#approval_name ⇒ String
The name of the approval being approved.
-
#properties ⇒ Hash<String,String>
Set of properties that should be associated with the account.
-
#reason ⇒ String
Free form text string explaining the approval reason.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ApproveAccountRequest
constructor
A new instance of ApproveAccountRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ApproveAccountRequest
Returns a new instance of ApproveAccountRequest.
159 160 161 |
# File 'lib/google/apis/cloudcommerceprocurement_v1/classes.rb', line 159 def initialize(**args) update!(**args) end |
Instance Attribute Details
#approval_name ⇒ String
The name of the approval being approved. If absent and there is only one
approval possible, that approval will be granted. If absent and there are many
approvals possible, the request will fail with a 400 Bad Request. Optional.
Corresponds to the JSON property approvalName
146 147 148 |
# File 'lib/google/apis/cloudcommerceprocurement_v1/classes.rb', line 146 def approval_name @approval_name end |
#properties ⇒ Hash<String,String>
Set of properties that should be associated with the account. Optional.
Corresponds to the JSON property properties
151 152 153 |
# File 'lib/google/apis/cloudcommerceprocurement_v1/classes.rb', line 151 def properties @properties end |
#reason ⇒ String
Free form text string explaining the approval reason. Optional. Max allowed
length: 256 bytes. Longer strings will be truncated.
Corresponds to the JSON property reason
157 158 159 |
# File 'lib/google/apis/cloudcommerceprocurement_v1/classes.rb', line 157 def reason @reason end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
164 165 166 167 168 |
# File 'lib/google/apis/cloudcommerceprocurement_v1/classes.rb', line 164 def update!(**args) @approval_name = args[:approval_name] if args.key?(:approval_name) @properties = args[:properties] if args.key?(:properties) @reason = args[:reason] if args.key?(:reason) end |