Class: Google::Apis::CloudcommerceprocurementV1::ApproveEntitlementRequest
- Inherits:
-
Object
- Object
- Google::Apis::CloudcommerceprocurementV1::ApproveEntitlementRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudcommerceprocurement_v1/classes.rb,
lib/google/apis/cloudcommerceprocurement_v1/representations.rb,
lib/google/apis/cloudcommerceprocurement_v1/representations.rb
Overview
Request message for [PartnerProcurementService.ApproveEntitlement[].
Instance Attribute Summary collapse
-
#entitlement_migrated ⇒ String
Optional.
-
#properties ⇒ Hash<String,String>
Set of properties that should be associated with the entitlement.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ApproveEntitlementRequest
constructor
A new instance of ApproveEntitlementRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ApproveEntitlementRequest
Returns a new instance of ApproveEntitlementRequest.
207 208 209 |
# File 'lib/google/apis/cloudcommerceprocurement_v1/classes.rb', line 207 def initialize(**args) update!(**args) end |
Instance Attribute Details
#entitlement_migrated ⇒ String
Optional. The resource name of the entitlement that was migrated, with the
format providers/provider_id/entitlements/entitlement_id`. Should only be
sent when resources have been migrated from entitlement_migrated to the new
entitlement. Optional.
Corresponds to the JSON propertyentitlementMigrated`
200 201 202 |
# File 'lib/google/apis/cloudcommerceprocurement_v1/classes.rb', line 200 def entitlement_migrated @entitlement_migrated end |
#properties ⇒ Hash<String,String>
Set of properties that should be associated with the entitlement. Optional.
Corresponds to the JSON property properties
205 206 207 |
# File 'lib/google/apis/cloudcommerceprocurement_v1/classes.rb', line 205 def properties @properties end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
212 213 214 215 |
# File 'lib/google/apis/cloudcommerceprocurement_v1/classes.rb', line 212 def update!(**args) @entitlement_migrated = args[:entitlement_migrated] if args.key?(:entitlement_migrated) @properties = args[:properties] if args.key?(:properties) end |